@@ -16,16 +16,22 @@ import sys
 
 from oslo_config import cfg
 from oslo_log import log
+from oslo_service import sslutils
 from oslo_utils import strutils
 
 from ironic_python_agent import agent
 from ironic_python_agent import config
+from ironic_python_agent import utils
 
 CONF = cfg.CONF
 
 
 def run():
     """Entrypoint for IronicPythonAgent."""
+    # NOTE(dtantsur): this must happen very early of the files from
+    # /etc/ironic-python-agent.d won't be loaded
+    utils.copy_config_from_vmedia()
+
     log.register_options(CONF)
     CONF(args=sys.argv[1:])
     # Debug option comes from oslo.log, allow overriding it via kernel cmdline
@@ -34,6 +40,13 @@ def run():
         ipa_debug = strutils.bool_from_string(ipa_debug)
         CONF.set_override('debug', ipa_debug)
     log.setup(CONF, 'ironic-python-agent')
+    # Used for TLS configuration
+    sslutils.register_opts(CONF)
+
+    logger = log.getLogger(__name__)
+    logger.debug("Configuration:")
+    CONF.log_opt_values(logger, log.DEBUG)
+
     agent.IronicPythonAgent(CONF.api_url,
                             agent.Host(hostname=CONF.advertise_host,
                                        port=CONF.advertise_port),
@@ -46,4 +59,5 @@ def run():
                             CONF.lookup_interval,
                             CONF.standalone,
                             CONF.agent_token,
-                            CONF.hardware_initialization_delay).run()
+                            CONF.hardware_initialization_delay,
+                            CONF.advertise_protocol).run()
